This function sets up two identical lists, each containing a design matrix for the linear predictor of the logit of a dichotomous outcome under a full logistic model with main effects and product terms for two biallelic markers.
design.dichotomous(x,...)List containing the single design matrix with all terms forming the full 2-locus logistic model
list of character strings containing the indices of the variables in x involved in each term of the logistic model
identical to x.e
identical to x.l
A 2-column matrix of numeric values representing genotypes of biallelic markers, with one column per marker and one row per subject. The two homozygous genotypes must be coded 0 and 1, and the heterozygous genotype value depends on the genetic model: 0 (recessive), 1/2 (allelic) or 1 (dominant).
Additional arguments will be ignored, but must be allowed for compatibility with other design functions.
Alexandre Bureau <alexandre.bureau@msp.ulaval.ca>
The linear predictors (without intercept) of the logistic function for \(Y = 1\) against the reference level \(Y = 0\) has the form:
\(\eta_{11} X_{1} + \eta_{12} X_{2} + \eta_{13} X_{1} X_{2}\)
The design matrix for the above model is constructed by this function.
fat2Lpoly, design.full